# comment out when not pre-release
#define prel	rc2

%define fversion %{version}
%define subrel  1
%define rel	9

%define wxver		3.1.3
%define wxvershort	3.1

%define use_builtin_wxgtk	0
%{?_with_builtin_wxgtk: %global use_builtin_wxgtk 1}
%{?_without_builtin_wxgtk: %global use_builtin_wxgtk 0}

# use system portaudio (without) or bundled's one (with)
%bcond_with portaudio

# use system lv2 (without) or bundled's one (with)
%bcond_without lv2

Summary:	Free Audio Editor With Effects/Analysis Tools
Name:		audacity
Version:	2.4.2
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv2+
Group:		Sound/Editors and Converters
URL:		http://audacityteam.org/
Source0:	https://www.fosshub.com/Audacity.html/%{name}-minsrc-%{fversion}%{?prel}.tar.xz

%if %{use_builtin_wxgtk}
# get from here: https://github.com/wxWidgets/wxWidgets.git with:
# git clone --recurse-submodules https://github.com/audacity/wxWidgets/
Source1:	https://github.com/wxWidgets/wxWidgets/releases/download/v%{wxver}/wxWidgets-%{wxver}.tar.bz2
%endif

#gw use Alsa by default
Patch6:		audacity-2.0.4-alsa-by-default.patch
#fix build with system portaudio
Patch7:		audacity-2.3.3-Fix-building-against-the-system-portaudio-library.patch
# add missed revision ident (to be derived from git)
# use:
# cd src; git show -s --format="#define REV_LONG \"%H\"%n#define REV_TIME \"%cd\"%n" | tee ../src/RevisionIdent.h
Patch8:		audacity-2.4.2-provide-missed-RevisionIdent.patch
# temporary workaround to disable XMMINTRIN and SSE (to review if there are better ways)
Patch9:		audacity-2.4.2-force-noxmmintrin-nosse-lame.patch
# a better patch for xmmintrin problem on i586 building
Patch10:	audacity-2.4.2-fix-libmp3lame-xmmintrin-no-sse.patch
# Fix libmp3lame detection from cmake
Patch11:	audacity-2.4.2-fix-libmp3lame-as-system.patch
# cosmetic: switch default theme to dark
Patch20:	audacity-2.4.2-default-theme-dark.patch

# Security fixes
Patch2000:  audacity-minsrc-2.3.1-fix-CVE-2020-11867.patch

BuildRequires:	autoconf
BuildRequires:	cmake >= 1:3.15
BuildRequires:	fftw-devel >= 2.1.4
BuildRequires:	gettext-devel
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(flac++)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(id3tag)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(soundtouch) >= 1.3.0
BuildRequires:  pkgconfig(soxr)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(twolame)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	vamp-plugin-sdk-devel
BuildRequires:	pkgconfig(expat)
BuildRequires:	ffmpeg-devel
%if %{with portaudio}
BuildRequires:	pkgconfig(portaudio-2.0)
%endif
%if %{with lv2}
BuildRequires:	pkgconfig(lv2) > 1.16.0
%endif
BuildRequires:	pkgconfig(suil-0)
BuildRequires:	pkgconfig(lilv-0)
#for compressing the help file:
BuildRequires:	zip

%if %{use_builtin_wxgtk}
BuildRequires:	bakefile
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libmspack)
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
BuildRequires:	pkgconfig(gtk+-3.0)
%else
BuildRequires:	wxgtk-devel >= 3.1.3
%endif
BuildRequires:	nasm
BuildRequires:	lame-devel
#
# Required by virtual:world of local lv2
%if %{without lv2}
BuildRequires:	pkgconfig(gtk+-x11-2.0)
BuildRequires:	pkgconfig(gtk+-x11-3.0)
BuildRequires:	pkgconfig(QtGui)
BuildRequires:	pkgconfig(Qt5Widgets)
%endif

Recommends:	%mklibname lame 0

%if %{without portaudio}
Provides:	bundled(portaudio) = 19
%endif
%if %{use_builtin_wxgtk}
Provides:	bundled(wxgtk) = 3.1.3
%endif


%description
Audacity is a program that lets you manipulate digital audio waveforms.

In addition to letting you record sounds directly from within the program,
it imports many sound file formats, including WAV, AIFF, MP3 and Ogg/Vorbis.
It supports all common editing operations such as Cut, Copy, and Paste, plus
it will mix tracks and let you apply plug-in effects to any part of a sound.
It also has a built-in amplitude envelope editor, a customizable spectrogram
mode and a frequency analysis window for audio analysis applications.

%prep
%if %{use_builtin_wxgtk}
%setup -q -n %{name}-minsrc-%{fversion} -a 1
%else
%setup -q -n %{name}-minsrc-%{fversion}
%endif

%patch6 -p1 -b .alsa-by-default

%if %{with portaudio}
%patch7 -p1 -b .system-portaudio
%endif

%patch8 -p1 -b .revision-ident

# force disable sse/sse2 for 32bit
%ifarch %ix86
%patch9 -p1 -b .nosse
%endif
# fix sse's xmmintrin
%patch10 -p1 -b .xmmintrin

# fix detection of libmp3lame
%patch11 -p1 -b .pkgconfig

# use dark theme as default
#patch20 -p1 -b .dark

# use dark theme as default
%patch2000 -p1 -b .CVE-2020-11867

chmod 644 *.txt

%build
%if %{use_builtin_wxgtk}
(cd wxWidgets-%{wxver}
 aclocal --force -I $PWD/build/aclocal
 autoconf -f
 libtoolize --copy --force
 CFLAGS="%{optflags} -fno-strict-aliasing" \
 CXXFLAGS="%{optflags} -fno-strict-aliasing" \
 ./configure \
   --prefix=$PWD/../%{name}_binlibs \
   --with-gtk=3 \
   --disable-shared \
   --enable-monolithic \
   --with-libpng=sys \
   --with-libjpeg=sys \
   --with-libtiff=sys \
   --with-zlib=sys \
   --with-expat=sys \
   --with-regex=builtin \
   --with-libmspack
 make -j $(nproc)
 make install
)
%endif

%if %{use_builtin_wxgtk}
export PATH=$PWD/%{name}_binlibs/bin:$PATH
%endif

# list of cmake options:
# https://wiki.audacityteam.org/wiki/CMake_Options#Lin
#
# other instructions:
# https://wiki.audacityteam.org/wiki/Building_On_Linux

# fix system lame detection
export PKG_CONFIG_PATH=$(pwd):$PKG_CONFIG_PATH

%cmake \
%if %{use_builtin_wxgtk}
    -Daudacity_use_wxwidgets=local \
%endif
    -Daudacity_use_ffmpeg=linked \
    -Daudacity_use_vorbis=system \
    -Daudacity_use_mad=system \
    -Daudacity_use_sndfile=system \
    -Daudacity_use_id3tag=system \
    -Daudacity_use_soundtouch=system \
%if %{with portaudio}
    -Daudacity_use_portaudio=system \
%else
    -Daudacity_use_portaudio=local \
%endif
%if %{with lv2}
    -Daudacity_use_lv2=system \
%else
    -Daudacity_use_lv2=local \
%endif
%ifarch %ix86
    -DHAVE_SSE=OFF \
    -DHAVE_SSE2=OFF \
%endif
    -Daudacity_use_twolame=system \
    -Daudacity_use_lame=system

%cmake_build

%install
%cmake_install

%find_lang %{name}

#install mime-type icon for .aup files (mga#27644)
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/mimetypes/
ln -s ../apps/audacity.svg %{buildroot}%{_iconsdir}/hicolor/scalable/mimetypes/application-x-audacity-project.svg

#clean uneeded installed but not packaged
rm -rf %{buildroot}%{_docdir}/*

#gw work around bug #52526
mkdir -p %{buildroot}%{_datadir}/%{name}/help/manual

%files -f %{name}.lang
%{_bindir}/*
%if %{without lv2}
%{_libdir}/%{name}/*.so
%endif
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/*/*.svg
%{_datadir}/icons/hicolor/*/%{name}.png
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/%{name}.1*
%{_datadir}/appdata/audacity.appdata.xml


%changelog
* Wed Jan 05 2022 wally <wally> 2.4.2-9.1.mga8
+ Revision: 1766960
- rebuild for wxgtk 3.1.5 (mga#29848)

* Fri Jan 01 2021 wally <wally> 2.4.2-9.mga8
+ Revision: 1667689
- rebuild for wxgtk pre 3.1.5 snapshot

* Thu Dec 24 2020 neoclust <neoclust> 2.4.2-8.mga8
+ Revision: 1663403
- Add P2000 in order to fix CVE-2020-11867

* Sun Nov 22 2020 wally <wally> 2.4.2-7.mga8
+ Revision: 1648553
- install mime-type icon for .aup files (mga#27644)

* Sun Aug 16 2020 wally <wally> 2.4.2-6.mga8
+ Revision: 1614327
- rebuild for new wxgtk 3.1.4

* Wed Jul 01 2020 ghibo <ghibo> 2.4.2-5.mga8
+ Revision: 1600968
- Rebuilt against newer lv2 system library.
- Introduce a conditional flag, so that either the BR and files list are matched when the local lv2 library is used instead of the system one.
- Fix cmake BR

* Tue Jun 30 2020 ghibo <ghibo> 2.4.2-4.mga8
+ Revision: 1600794
- Revert dark to light theme (audience has not appreciated)

* Tue Jun 30 2020 ghibo <ghibo> 2.4.2-3.mga8
+ Revision: 1600654
- Fix doc for getting wxwidgets for local building
- Completing system lame detection patch

* Tue Jun 30 2020 ghibo <ghibo> 2.4.2-2.mga8
+ Revision: 1600634
- Re-enable my original patch for building under i586
- Switch to dark theme as default.
- Use alternative patch for getting local lame building under i586.
- Prepare patch for using system-wide lame lib instead of local one.
- Cleanup unused stuff for older autoconf.
- Add extra BR due to lv2 system lib not correctly detected.
- fix comment for nosse patch
- Use %%ix86 macro for disabling sse/sse2
- Add instructions to build RevisionIdent.h

* Tue Jun 30 2020 ghibo <ghibo> 2.4.2-1.mga8
+ Revision: 1600581
- Add patch to force disable XMMINTRIN and SSE for lame
- Provide missed RevisionIdent.h from git
- Fix wxgtk-devel minimal requirement to release 3.1.3 (from doc)
- switch ffmpeg cmake config flag to linked
- Removing system lame-devel from BR (because not correctly detected)
- use -Daudacity_use_twolame instead of -Dwith-libtwolame (unused).
- Use local portaudio (system portaudio is no longer supported)
- Remove comment in the middle of a cmake config
- use portaudio as local
- Update cmake options according to audacity site table
- Add nasm to BR
- Use lame as system for i586 because of missed sse instructions
- Add lame-devel to BR
- Disable SSE and SSE2 for i586
- Disable sse and sse2 for i586.
- Provide minimal cmake requirement version in BR.
- Update bundled stable wxgtk version to 3.0.5.
+ joequant <joequant>
- fix typo in patch
- remove arm workaround
+ zezinho <zezinho>
- switch to cmake
- new version 2.4.2

* Tue Feb 18 2020 umeabot <umeabot> 2.3.3-2.mga8
+ Revision: 1538787
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 26 2019 zezinho <zezinho> 2.3.3-1.mga8
+ Revision: 1462898
- new version 2.3.3
- new version 2.3.3

* Tue Nov 12 2019 wally <wally> 2.3.2-6.mga8
+ Revision: 1459453
- rebuild for wxgtk 3.1.3

* Fri Oct 25 2019 daviddavid <daviddavid> 2.3.2-5.mga8
+ Revision: 1455801
- add upstream patch to fix missing Spanish language choice on Linux (mga#24965)
- conditional portaudio

* Tue Oct 22 2019 daviddavid <daviddavid> 2.3.2-4.mga8
+ Revision: 1455126
- use system portaudio

* Mon Jul 08 2019 wally <wally> 2.3.2-3.mga8
+ Revision: 1419521
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sat Jun 29 2019 wally <wally> 2.3.2-2.mga8
+ Revision: 1416077
- rebuild for gtk3 enabled wxgtk 3.1.2

* Tue Jun 18 2019 zezinho <zezinho> 2.3.2-1.mga7
+ Revision: 1400238
- new version 2.3.2

* Thu Mar 14 2019 zezinho <zezinho> 2.3.1-1.mga7
+ Revision: 1376857
- new version 2.3.1

* Sun Mar 10 2019 daviddavid <daviddavid> 2.2.2-6.mga7
+ Revision: 1373687
- build builtin wxgtk without webkitgtk-3.0 support

* Fri Sep 21 2018 umeabot <umeabot> 2.2.2-5.mga7
+ Revision: 1295120
- Mageia 7 Mass Rebuild

* Fri Jul 13 2018 wally <wally> 2.2.2-4.mga7
+ Revision: 1243432
- fix build on aarch64

* Sat May 05 2018 wally <wally> 2.2.2-3.mga7
+ Revision: 1226268
- add provides for bundled wxgtk and portaudio
+ daviddavid <daviddavid>
- rebuild for new ffmpeg 4.0

* Sun Mar 04 2018 zezinho <zezinho> 2.2.2-2.mga7
+ Revision: 1206554
- new version 2.2.2

* Sat Feb 03 2018 zezinho <zezinho> 2.2.1-2.mga7
+ Revision: 1198703
- rebuild against new vamp-plugins-sdk-2.7.1

* Wed Dec 27 2017 zezinho <zezinho> 2.2.1-1.mga7
+ Revision: 1185992
- build against bundled portaudio till upstream bug is fixed
- new version
- build against system portaudio lib

* Wed Dec 06 2017 zezinho <zezinho> 2.2.0-1.mga7
+ Revision: 1181518
- new version
- use bundled portaudio

* Sat Oct 07 2017 cjw <cjw> 2.1.3-8.mga7
+ Revision: 1169866
- drop unused build dependency on libgnomeprintui

* Fri Jun 09 2017 ghibo <ghibo> 2.1.3-7.mga6
+ Revision: 1107396
- Really apply Patch8.

* Thu Jun 08 2017 ghibo <ghibo> 2.1.3-6.mga6
+ Revision: 1107337
- Fix GUI ComboBox below "Project Rate" in the main window on the bottom of the screen.
- Merged Patch from Ubuntu to fix text fitting problems on recovery dialog window.

* Sat Jun 03 2017 ghibo <ghibo> 2.1.3-5.mga6
+ Revision: 1106196
- Update wxWidgets to release 3.0.3.1, in sync with system one
- Sync internal wxWidgets to 3.0.3.1, same as system one

* Sat Jun 03 2017 akien <akien> 2.1.3-4.mga6
+ Revision: 1106083
- Rebuild for wxgtk 3.0.3.1

* Tue May 02 2017 akien <akien> 2.1.3-3.mga6
+ Revision: 1098267
- Rebuild for ffmpeg 3.3

* Wed Mar 29 2017 ghibo <ghibo> 2.1.3-2.mga6
+ Revision: 1095245
+ rebuild (emptylog)

* Mon Mar 27 2017 ghibo <ghibo> 2.1.3-1.10.mga6
+ Revision: 1094933
- Use bundled wxwidgets 3.0.3-git, linked to gtk3 (added conditional build flag for this).
- Added Patch8 (fix typo in italian po files).
- Added Patch9 to create enough room for string requester to avoid charecters out of the string box.
- Backport Patch1006 from current git release (fixes wx assert in debug build).

* Wed Mar 08 2017 akien <akien> 2.1.2-4.mga6
+ Revision: 1089837
- Rebuild for ffmpeg 3.2.4

* Thu Jun 02 2016 daviddavid <daviddavid> 2.1.2-3.mga6
+ Revision: 1019806
- rebuild for wxgtk3.0 built with GTK2

* Sun May 29 2016 zezinho <zezinho> 2.1.2-2.mga6
+ Revision: 1019312
- rebuild against current gtk to try to fix display glitches

* Thu Jan 21 2016 luigiwalser <luigiwalser> 2.1.2-1.mga6
+ Revision: 926252
- 2.1.2 final
+ wally <wally>
- update URL

* Sun Jan 03 2016 daviddavid <daviddavid> 2.1.2-0.2.rc2.1.mga6
+ Revision: 918922
- new version: 2.1.2_rc2
- fix release tag

* Sat Jan 02 2016 luigiwalser <luigiwalser> 2.1.2-0.2.rc1.mga6
+ Revision: 918465
- rebuild for soundtouch

* Mon Dec 21 2015 zezinho <zezinho> 2.1.2-0.1.rc1.mga6
+ Revision: 913163
- new version
- new version

* Wed Sep 16 2015 shlomif <shlomif> 2.1.1-2.mga6
+ Revision: 879984
- Rebuild for new gcc and wxgtk2.8

* Thu Sep 10 2015 zezinho <zezinho> 2.1.1-1.mga6
+ Revision: 875724
- new version 2.1.1

* Fri Nov 14 2014 cjw <cjw> 2.0.6-2.mga5
+ Revision: 796924
- rebuild for ffmpeg 2.4

* Thu Oct 23 2014 cjw <cjw> 2.0.6-1.mga5
+ Revision: 792547
- 2.0.6
- drop patches 8,10,11: fixed upstream
- enable ffmpeg
- use system portaudio and lv2

* Wed Oct 15 2014 umeabot <umeabot> 2.0.5-5.mga5
+ Revision: 747556
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.5-4.mga5
+ Revision: 678040
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/
+ fwang <fwang>
- try build with system ffmpeg

* Tue Mar 04 2014 zezinho <zezinho> 2.0.5-2.mga5
+ Revision: 599570
- bump release to be upper than MGA4 update

* Mon Mar 03 2014 zezinho <zezinho> 2.0.5-1.mga5
+ Revision: 598889
- new version

* Sat Oct 19 2013 umeabot <umeabot> 2.0.4-3.mga4
+ Revision: 534214
- Mageia 4 Mass Rebuild

* Mon Sep 09 2013 fwang <fwang> 2.0.4-2.mga4
+ Revision: 476575
- disable ffmpeg build

* Mon Sep 09 2013 fwang <fwang> 2.0.4-1.mga4
+ Revision: 476570
- more linkage fix
- another link fix
- new version 2.0.4

* Sun Apr 07 2013 rtp <rtp> 2.0.3-2.mga3
+ Revision: 408953
- disable sse build on non x86

* Wed Mar 27 2013 dams <dams> 2.0.3-1.mga3
+ Revision: 405757
- new version 2.0.3

* Tue Feb 12 2013 fwang <fwang> 2.0.2-4.mga3
+ Revision: 398017
- disable ffmpeg build till upstream fix building with recent ffmpeg
- build with ffmpeg (bug#9043)

* Fri Jan 11 2013 umeabot <umeabot> 2.0.2-3.mga3
+ Revision: 346578
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 16 2012 zezinho <zezinho> 2.0.2-2.mga3
+ Revision: 318978
- change group
+ fwang <fwang>
- drop old requires

* Sat Aug 25 2012 fwang <fwang> 2.0.2-1.mga3
+ Revision: 283781
- new version 2.0.2

* Fri Jun 29 2012 fwang <fwang> 2.0.1-1.mga3
+ Revision: 264845
- update brs
- new version 2.0.1

* Wed Apr 18 2012 dams <dams> 2.0.0-1.mga2
+ Revision: 231438
- new version 2.0.0
- rediff patch

* Tue Jan 24 2012 zezinho <zezinho> 1.3.14-1.mga2
+ Revision: 200651
- patch to link to pthread
- patch to fix ffmpeg
- patch to fix gtypes
- rediff patch
- new version

* Mon Sep 19 2011 fwang <fwang> 1.3.13-2.mga2
+ Revision: 145289
- fix build with latest ffmpeg
- rebuild for new libpng

* Tue Jun 07 2011 ahmad <ahmad> 1.3.13-1.mga2
+ Revision: 101629
- Update to 1.3.13
- Rediff the desktopentry patch
- Drop patch1,11
- Update configure options (just '--with-portaudio' works)

* Tue Mar 08 2011 ennael <ennael> 1.3.12-3.mga1
+ Revision: 66674
- clean spec file
- imported package audacity

